@@ -1,6 +1,6 @@
 package MooseX::Role::BuildInstanceOf; {
 
-    our $VERSION = '0.06';
+    our $VERSION = '0.07';
     use MooseX::Role::Parameterized;
     use 5.008;
 
@@ -8,7 +8,6 @@ package MooseX::Role::BuildInstanceOf; {
         isa  => 'Str',
         is => 'ro',
         required => 1,
-        coerce => 1
     );
 
     sub decamelize {
@@ -57,6 +56,13 @@ package MooseX::Role::BuildInstanceOf; {
         default => sub { [] },
     );
 
+    parameter 'inherited_args' => (
+        isa  => 'ArrayRef',
+        is => 'ro',
+        required => 1,
+        default => sub { [] },
+    );
+
     parameter 'type' => (
         isa => 'Str',
         is => 'ro',
@@ -125,6 +131,34 @@ package MooseX::Role::BuildInstanceOf; {
             return $parameters->fixed_args;
         };
 
+        has $prefix."_inherited_args" => (
+            is => 'ro',
+            init_arg => undef,
+            isa => 'ArrayRef',
+            lazy_build => 1,
+        );
+
+        method "_build_". $prefix ."_inherited_args" => sub {
+            my $self = shift;
+
+            my @args = @{ $parameters->inherited_args };
+
+            my %resolved_args;
+
+            for my $arg ( @args ) {
+                if ( ! ref $arg ) {
+                    $resolved_args{ $arg } = $self->$arg;
+                }
+                elsif( ref $arg eq 'HASH' ) {
+                    while( my ($k,$v) = each %$arg ) {
+                        $resolved_args{ $k } = ref $v ? $v->($self) : $self->$v;
+                    }
+                }
+            }
+
+            return [ %resolved_args ];
+        };
+
         ## This needs to be broken out into roles or something
         ## not so lame...
 
@@ -163,8 +197,10 @@ package MooseX::Role::BuildInstanceOf; {
         method "merge_".$prefix ."_args" => sub {
             my $self = shift @_;
             my $fixed_args = $prefix."_fixed_args";
+            my $inherited_args = $prefix."_inherited_args";
             my $args = $prefix."_args";
             return (
+                @{ $self->$inherited_args },
                 @{$self->$fixed_args},
                 @{$self->$args},
             );
@@ -236,7 +272,7 @@ and builds the following code into your class:
     );
 
     sub _build_photo_args {
-        return []; 
+        return [];
     };
 
     has photo_fixed_args => (
@@ -284,7 +320,7 @@ for examples.
 You can now instantiate your class with the following (assuming your MyApp::Photos
 class defines a 'source_dir' attribute.)
 
-    my $album = MyApp::Album(photo_args=>[source_dir=>'~/photos']);
+    my $album = MyApp::Album->new(photo_args=>[source_dir=>'~/photos']);
 
 The overall goal here being to allow you to defer choice of class and arguments
 to when the class is actually used, thus achieving maximum flexibility.  We can
@@ -615,6 +651,40 @@ instantiation time.  If your subclasses really need to do this, they would
 need to override some of the generated methods.  See the next section for
 more information.
 
+=head2 inherited_args 
+
+Additional args copied from the current class and passed to the target class 
+at instantiation time. Individual args can be passed as strings (which is
+assumed to be the argument name, both the current and target classes),
+or as a hash ref. In the latter case, the hash's keys are the name of the 
+attribute in the target class, and the value can either be a string (name
+of the attribute in the main class) or a coderef (which will be evaluated
+with the master object to determine the argument value).  
+
+    package MyApp::Album;
+    use Moose;
+
+    has root_dir  => ( is => 'ro' );
+    has is_public => ( is => 'ro' );
+
+    with 'MooseX::Role::BuildInstanceOf' => {
+        target => 'MyApp::Image',
+        inherited_args => [ 
+            'root_dir', 
+            { world_visible => 'is_public' },
+            { parent_album => sub { shift @_ } },
+        }
+    };
+
+In this example, the creation of the image target object
+would be quivalent to
+
+    $image = MyApp::Image->new(
+        root_dir      => $album->root_dir,
+        world_visible => $album->is_public,
+        parent_album  => $album,
+    );
+
 =head2 type
 
 By default we create an attribute that holds an instance of the 'target'.
@@ -659,6 +729,11 @@ be overidden by the person instantiating the class.  Your subclassers, however
 can, if they are willing to go to trouble (see section below under GENERATED
 METHODS for more.)
 
+=head3 {$prefix}_inherited_args
+
+Additional args copied from the current class and passed to the target class 
+at instantiation time. 
+
 =head2 {$prefix}
 
 Contains an instance of the target class (the class name found in {$prefix}_class.)
@@ -702,6 +777,10 @@ they want to set different defaults.
 
 as above but for the fixed_args.
 
+=head3 _build_{$prefix}_inherited_args
+
+as above but for the inherited_args.
+
 =head3 _build_{$prefix}
 
 You may wish to modify this if you want more control over how your classes are
@@ -796,7 +875,7 @@ can just loop:
 
 Which would save you even more boilerplate / repeated code.
 
-=head2 You want additional type constraints on the generated atrributes.
+=head2 You want additional type constraints on the generated attributes.
 
 Sometimes you may wish to ensure that the generated attribute conforms to a 
 particular interface.  You can use stand Moose syntax to add or override any
@@ -815,7 +894,7 @@ particular Role.
 
 Generally speaking, I believe this role is best suited for usage in a sort of 
 'middle' complexity level.  That is, when the app has become somewhat complex
-but not yet so much as to warrent seeking out an IOC solution, of which 
+but not yet so much as to warrant seeking out an IOC solution, of which 
 L<Bread::Board> is an ideal candidate.  However this is not to say that IOC
 containers in general and L<Bread::Board> in particular cannot scale downward.
 In fact such a system may be useful even for relatively small projects.  My 
